package com.xunmei.system.service;

import java.util.List;

import com.xunmei.system.domain.SysAreaCheck;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xunmei.common.core.web.page.TableDataInfo;

/**
 * 区域采集点Service接口
 *
 * @author xunmei
 * @date 2023-08-15
 */
public interface ISysAreaCheckService extends IService<SysAreaCheck> {
    /**
     * 查询区域采集点
     *
     * @param id 区域采集点主键
     * @return 区域采集点
     */
    SysAreaCheck selectSysAreaCheckById(Long id);

    /**
     * 查询区域采集点列表
     *
     * @param sysAreaCheck 区域采集点
     * @return 区域采集点集合
     */
    List<SysAreaCheck> selectSysAreaCheckList(SysAreaCheck sysAreaCheck);

    /**
     * 新增区域采集点
     *
     * @param sysAreaCheck 区域采集点
     * @return 结果
     */
    int insertSysAreaCheck(SysAreaCheck sysAreaCheck);

    /**
     * 修改区域采集点
     *
     * @param sysAreaCheck 区域采集点
     * @return 结果
     */
    int updateSysAreaCheck(SysAreaCheck sysAreaCheck);

    /**
     * 批量删除区域采集点
     *
     * @param ids 需要删除的区域采集点主键集合
     * @return 结果
     */
    int deleteSysAreaCheckByIds(Long[] ids);

    /**
     * 删除区域采集点信息
     *
     * @param id 区域采集点主键
     * @return 结果
     */
    int deleteSysAreaCheckById(Long id);

    /**
     * 查询区域采集点分页数据
     *
     * @param sysAreaCheck 查询条件对象
     * @return Page
     */
    TableDataInfo<SysAreaCheck> selectPage(SysAreaCheck sysAreaCheck);

    /**
     * 根据id获取区域
     * @param areaId
     * @return
     */
    List<SysAreaCheck> selectByAreaId(Long areaId);
}
