package com.xunmei.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.xunmei.system.domain.SysAreaCheck;
import com.xunmei.system.domain.vo.SysAreaCheckVO;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;



/**
 * 区域采集点Mapper接口
 *
 * @author xunmei
 * @date 2023-08-15
 */
@Mapper
public interface SysAreaCheckMapper extends BaseMapper<SysAreaCheck> {

    /**
     * 查询区域采集点
     *
     * @param id 区域采集点主键
     * @return 区域采集点
     */
     SysAreaCheck selectSysAreaCheckById(Long id);


    /**
     * 查询区域采集点列表
     *
     * @param sysAreaCheck 区域采集点
     * @return 区域采集点集合
     */
     List<SysAreaCheck> selectSysAreaCheckList(SysAreaCheck sysAreaCheck);
IPage<SysAreaCheckVO> selectByPage(IPage<?>page,Integer id);
    /**
     * 新增区域采集点
     *
     * @param sysAreaCheck 区域采集点
     * @return 结果
     */
     int insertSysAreaCheck(SysAreaCheck sysAreaCheck);

    /**
     * 修改区域采集点
     *
     * @param sysAreaCheck 区域采集点
     * @return 结果
     */
     int updateSysAreaCheck(SysAreaCheck sysAreaCheck);

    /**
     * 删除区域采集点
     *
     * @param id 区域采集点主键
     * @return 结果
     */
     int deleteSysAreaCheckById(Long id);

    /**
     * 批量删除区域采集点
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteSysAreaCheckByIds(Long[] ids);
}
